m4-commit
[Top][All Lists]
Advanced

[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]

Changes to m4/m4/debug.c,v


From: Eric Blake
Subject: Changes to m4/m4/debug.c,v
Date: Wed, 09 Aug 2006 21:33:26 +0000

CVSROOT:        /sources/m4
Module name:    m4
Changes by:     Eric Blake <ericb>      06/08/09 21:33:24

Index: m4/debug.c
===================================================================
RCS file: /sources/m4/m4/m4/debug.c,v
retrieving revision 1.20
retrieving revision 1.21
diff -u -b -r1.20 -r1.21
--- m4/debug.c  1 May 2005 11:10:05 -0000       1.20
+++ m4/debug.c  9 Aug 2006 21:33:24 -0000       1.21
@@ -1,5 +1,5 @@
 /* GNU m4 -- A simple macro processor
-   Copyright (C) 1991, 1992, 1993, 1994 Free Software Foundation, Inc.
+   Copyright (C) 1991, 1992, 1993, 1994, 2006 Free Software Foundation, Inc.
 
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
@@ -159,7 +159,7 @@
   return true;
 }
 
 /* Print the header of a one-line debug message, starting by "m4 debug".  */
 void
 m4_debug_message_prefix (m4 *context)
 {
@@ -168,9 +168,12 @@
   assert (context);
 
   debug_file = m4_get_debug_file (context);
-  fprintf (debug_file, "m4 debug: ");
+  fprintf (debug_file, "m4debug:");
+  if (m4_get_current_line (context))
+    {
   if (m4_is_debug_bit (context, M4_DEBUG_TRACE_FILE))
-    fprintf (debug_file, "%s: ", m4_current_file);
+       fprintf (debug_file, "%s:", m4_get_current_file (context));
   if (m4_is_debug_bit (context, M4_DEBUG_TRACE_LINE))
-    fprintf (debug_file, "%d: ", m4_current_line);
+       fprintf (debug_file, "%d:", m4_get_current_line (context));
+    }
 }
@@ -159,7 +159,7 @@
 }
 
-/* Print the header of a one-line debug message, starting by "m4 debug".  */
+/* Print the header of a one-line debug message, starting with "m4debug:".  */
 void
 m4_debug_message_prefix (m4 *context)




reply via email to

[Prev in Thread] Current Thread [Next in Thread]